{% extends "checkout/checkout.html" %}

{% block shipping_address %}

<h4>Delete address?</h4>
<form action="." method="post">
    {% csrf_token %}
	{{ object.summary }}
    <p>Are you sure you want to delete this address? <input type="submit" value="Yes!" /></p>
</form>

{% endblock shipping_address %}
